@@ -1,7 +1,7 @@
 import re
 from typing import Any
 
-_PATTERN = re.compile(r"(?<!^)(?=[A-Z])")
+_CAMEL_CASE_PATTERN = re.compile(r"(?<!^)(?=[A-Z])")
 
 
 def snake_to_camel(name: str, overrides: dict[str, str] | None = None) -> str:
@@ -26,7 +26,23 @@ def camel_to_snake(s: str) -> str:
     """
     Converts `s` from camel case to snake case.
     """
-    return _PATTERN.sub("_", s).lower()
+    return _CAMEL_CASE_PATTERN.sub("_", s).lower()
+
+
+def split_pascal_case(s: str) -> str:
+    """
+    Splits strings in pascal case into a sentence.
+
+    Examples:
+
+    assert split_pascal_case("FooBar") == "Foo bar"
+    assert split_pascal_case("Foo") == "Foo"
+    """
+    if not s:
+        return s
+
+    words = re.findall(r"[A-Z][a-z]*", s)
+    return " ".join([words[0]] + [word.lower() for word in words[1:]])
 
 
 def convert_dict_keys_to_snake_case(d: dict[str, Any]) -> dict[str, Any]:
